@@ -31,7 +31,10 @@ class CreateEBook:
         if os.path.exists(ebook_path):
             logging.error(ebook_path + " does not exist")
             return False, ""
+        data = re.sub(r'[\\/*?:"<>|!]', "", name)
+        data = data[data.find("]")+1:]
+        name = data[:data.find("[")].strip()
         logging.info("Generating Books", pdf_path)
-        ebook = self.base_cmd + ' "' + pdf_path + '" ' + '"' + "".join(ebook_path.split(".")[:-1].strip()) + '.mobi"'
+        ebook = self.base_cmd + ' "' + pdf_path + '" ' + '"' + "".join(ebook_path.split(".")[:-1].strip())+name + '.mobi"'
         subprocess.call(ebook, shell=True)
         return True, ebook_path
